@@ -1,7 +1,7 @@
 /***************************************************************************
  begin                : Wed Aug 21 2002
  copyright            : (C) 2002 by Christian Hubinger
- email                : chubinger@gmail.com.orphi.iki
+ email                : chubinger@irrsinnig.org.orphi.iki
 ***************************************************************************/
 
 /***************************************************************************
@@ -23,9 +23,12 @@
 /**
   *@author Christian Hubinger
   */
-class KMFIPTDoc;
+
 class QString;
 
+namespace KMF {
+class KMFIPTDoc;
+
 class KDE_EXPORT KMFIPTDocOptions : public KMyFirewallIPTDocOptions {
 	Q_OBJECT
 public:
@@ -42,5 +45,5 @@ signals:
 	void sigConfigChanged();
 
 };
-
+}
 #endif
